==> knative-model-6.5.0-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1alpha1/PlacementFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementFluentImpl<A extends PlacementFluent<A>> extends BaseFluent<A> implements PlacementFluent<A>{
  public PlacementFluentImpl() {
  }
  public PlacementFluentImpl(Placement instance) {
    this.withPodName(instance.getPodName()); 
    this.withVreplicas(instance.getVreplicas()); 
  }
  private String podName;
  private Integer vreplicas;
  public String getPodName() {
    return this.podName;
  }
  public A withPodName(String podName) {
    this.podName=podName; return (A) this;
  }
  public Boolean hasPodName() {
    return this.podName != null;
  }
  public Integer getVreplicas() {
    return this.vreplicas;
  }
  public A withVreplicas(Integer vreplicas) {
    this.vreplicas=vreplicas; return (A) this;
  }
  public Boolean hasVreplicas() {
    return this.vreplicas != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PlacementFluentImpl that = (PlacementFluentImpl) o;
    if (podName != null ? !podName.equals(that.podName) :that.podName != null) return false;
    if (vreplicas != null ? !vreplicas.equals(that.vreplicas) :that.vreplicas != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(podName,  vreplicas,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (podName != null) { sb.append("podName:"); sb.append(podName + ","); }
    if (vreplicas != null) { sb.append("vreplicas:"); sb.append(vreplicas); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1alpha1/PlacementFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementFluentImpl<A extends PlacementFluent<A>> extends BaseFluent<A> implements PlacementFluent<A>{
  public PlacementFluentImpl() {
  }
  public PlacementFluentImpl(Placement instance) {
    if (instance != null) {
      this.withPodName(instance.getPodName());
      this.withVreplicas(instance.getVreplicas());
    }
  }
  private String podName;
  private Integer vreplicas;
  public String getPodName() {
    return this.podName;
  }
  public A withPodName(String podName) {
    this.podName=podName; return (A) this;
  }
  public Boolean hasPodName() {
    return this.podName != null;
  }
  public Integer getVreplicas() {
    return this.vreplicas;
  }
  public A withVreplicas(Integer vreplicas) {
    this.vreplicas=vreplicas; return (A) this;
  }
  public Boolean hasVreplicas() {
    return this.vreplicas != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementFluentImpl that = (PlacementFluentImpl) o;
    if (!java.util.Objects.equals(podName, that.podName)) return false;

    if (!java.util.Objects.equals(vreplicas, that.vreplicas)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(podName,  vreplicas,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (podName != null) { sb.append("podName:"); sb.append(podName + ","); }
    if (vreplicas != null) { sb.append("vreplicas:"); sb.append(vreplicas); }
    sb.append("}");
    return sb.toString();
  }
  
}
